==> apache-jena-3.16.0.zip: org/apache/jena/sparql/path/P_FixedLength.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.jena.sparql.path;

import org.apache.jena.sparql.util.NodeIsomorphismMap;

public class P_FixedLength extends P_Path1 {
    private final long count;

    public P_FixedLength(Path p, long count) {
        super(p);
        this.count = count;
    }

    @Override
    public boolean equalTo(Path path2, NodeIsomorphismMap isoMap) {
        if ( !(path2 instanceof P_FixedLength) )
            return false;
        P_FixedLength other = (P_FixedLength)path2;
        return other.count == count && getSubPath().equalTo(other.getSubPath(), isoMap);
    }

    public long getCount() {
        return count;
    }

    @Override
    public int hashCode() {
        return hashFixedLength ^ (int)count ^ getSubPath().hashCode();
    }

    @Override
    public void visit(PathVisitor visitor) {
        visitor.visit(this);
    }

}

==> apache-jena-5.6.0.zip: org/apache/jena/sparql/path/P_FixedLength.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.jena.sparql.path;

import org.apache.jena.sparql.util.NodeIsomorphismMap;

public class P_FixedLength extends P_Path1 {
    private final long count;

    public P_FixedLength(Path p, long count) {
        super(p);
        this.count = count;
    }

    @Override
    public boolean equalTo(Path path2, NodeIsomorphismMap isoMap) {
        if ( path2 instanceof P_FixedLength other )
            return other.count == count && getSubPath().equalTo(other.getSubPath(), isoMap);
        return false;
    }

    public long getCount() {
        return count;
    }

    @Override
    public int hashCode() {
        return hashFixedLength ^ (int)count ^ getSubPath().hashCode();
    }

    @Override
    public void visit(PathVisitor visitor) {
        visitor.visit(this);
    }

}
